PERF Analysis

Summary

### Basic Info

#### Genome info

Fasta file: name
Total size: genomeSize
GC %: GC
No.of sequences: numSeq

#### Repeat info

Repeat occurrences: totalRepFreq
Total repeat bases: totalRepBases
Percent genome covered: percentGenomeCovered
Repeat classes: numRepClass/501
Repeat occurrences per MB: repDensityByFreq
Repeat bases per MB: repDensityByBases

### Most repeat unit occurrences

Sequence id | Start | End | Repeat class | Length | Strand | Repeat units | Actual repeat
--- | --- | --- | --- | --- | --- | --- | ---

### Longest repeat occurrences

Sequence id | Start | End | Repeat class | Length | Strand | Repeat units | Actual repeat
--- | --- | --- | --- | --- | --- | --- | ---

Repeat Frequency
Sort Selection
Show
Repeats
Repeat Selection
Sort by frequency
Sort alphabetically
Repeat Distribution
Data type
Frequency
Bases covered
Group by length
On
Off
Repeat Selection
Sequence Length vs Frequency
Length Range
Min :
Max:
Repeat Selection